@@ -1,5 +1,5 @@
 """
-Overall pipeline to train the model.  It parses arguments, and trains a DeText model.
+Overall pipeline to train the model.  It parses arguments, and trains a CLSM model.
 """
 
 import sys
@@ -57,8 +57,8 @@ def add_arguments(parser):
     parser.add_argument("--bert_checkpoint", type=str, default=None, help="pretrained bert model checkpoint.")
 
     # LSTM related
-    parser.add_argument("--unit_type", type=str, default="lstm", choices=["lstm"],
-                        help="RNN cell unit type. Currently only supports lstm. Will support other cell types in the future")
+    parser.add_argument("--unit_type", type=str, default="lstm",
+                        help="RNN cell unit type. Support lstm/gru/layer_norm_lstm")
     parser.add_argument("--num_layers", type=int, default=1, help="RNN layers")
     parser.add_argument("--num_residual_layers", type=int, default=0,
                         help="Number of residual layers from top to bottom. For example, if `num_layers=4` and "
@@ -292,13 +292,15 @@ def main(argv):
 
         misc_utils.save_hparams(hparams.out_dir, hparams)
 
+        # set up logger
+        sys.stdout = logger.Logger(os.path.join(hparams.out_dir, 'logging.txt'))
     else:
         # TODO: move removal/creation to a hadoopShellJob st. it does not reside in distributed training code.
         logging.info("Waiting for chief to remove/create directories.")
         # Wait for dir created form chief
         time.sleep(10)
 
-    if task_type == executor_utils.EVALUATOR or task_type == executor_utils.LOCAL_MODE:
+    if task_type == executor_utils.EVALUATOR:
         # set up logger for evaluator
         sys.stdout = logger.Logger(os.path.join(hparams.out_dir, 'eval_log.txt'))
 
